@@ -23,48 +23,48 @@ else:
 
 __all__ = (
     "AccessLogTypeDef",
-    "AddAvailabilityZonesInputTypeDef",
-    "AddAvailabilityZonesOutputResponseTypeDef",
-    "AddTagsInputTypeDef",
+    "AddAvailabilityZonesInputRequestTypeDef",
+    "AddAvailabilityZonesOutputTypeDef",
+    "AddTagsInputRequestTypeDef",
     "AdditionalAttributeTypeDef",
     "AppCookieStickinessPolicyTypeDef",
-    "ApplySecurityGroupsToLoadBalancerInputTypeDef",
-    "ApplySecurityGroupsToLoadBalancerOutputResponseTypeDef",
-    "AttachLoadBalancerToSubnetsInputTypeDef",
-    "AttachLoadBalancerToSubnetsOutputResponseTypeDef",
+    "ApplySecurityGroupsToLoadBalancerInputRequestTypeDef",
+    "ApplySecurityGroupsToLoadBalancerOutputTypeDef",
+    "AttachLoadBalancerToSubnetsInputRequestTypeDef",
+    "AttachLoadBalancerToSubnetsOutputTypeDef",
     "BackendServerDescriptionTypeDef",
-    "ConfigureHealthCheckInputTypeDef",
-    "ConfigureHealthCheckOutputResponseTypeDef",
+    "ConfigureHealthCheckInputRequestTypeDef",
+    "ConfigureHealthCheckOutputTypeDef",
     "ConnectionDrainingTypeDef",
     "ConnectionSettingsTypeDef",
-    "CreateAccessPointInputTypeDef",
-    "CreateAccessPointOutputResponseTypeDef",
-    "CreateAppCookieStickinessPolicyInputTypeDef",
-    "CreateLBCookieStickinessPolicyInputTypeDef",
-    "CreateLoadBalancerListenerInputTypeDef",
-    "CreateLoadBalancerPolicyInputTypeDef",
+    "CreateAccessPointInputRequestTypeDef",
+    "CreateAccessPointOutputTypeDef",
+    "CreateAppCookieStickinessPolicyInputRequestTypeDef",
+    "CreateLBCookieStickinessPolicyInputRequestTypeDef",
+    "CreateLoadBalancerListenerInputRequestTypeDef",
+    "CreateLoadBalancerPolicyInputRequestTypeDef",
     "CrossZoneLoadBalancingTypeDef",
-    "DeleteAccessPointInputTypeDef",
-    "DeleteLoadBalancerListenerInputTypeDef",
-    "DeleteLoadBalancerPolicyInputTypeDef",
-    "DeregisterEndPointsInputTypeDef",
-    "DeregisterEndPointsOutputResponseTypeDef",
-    "DescribeAccessPointsInputTypeDef",
-    "DescribeAccessPointsOutputResponseTypeDef",
-    "DescribeAccountLimitsInputTypeDef",
-    "DescribeAccountLimitsOutputResponseTypeDef",
-    "DescribeEndPointStateInputTypeDef",
-    "DescribeEndPointStateOutputResponseTypeDef",
-    "DescribeLoadBalancerAttributesInputTypeDef",
-    "DescribeLoadBalancerAttributesOutputResponseTypeDef",
-    "DescribeLoadBalancerPoliciesInputTypeDef",
-    "DescribeLoadBalancerPoliciesOutputResponseTypeDef",
-    "DescribeLoadBalancerPolicyTypesInputTypeDef",
-    "DescribeLoadBalancerPolicyTypesOutputResponseTypeDef",
-    "DescribeTagsInputTypeDef",
-    "DescribeTagsOutputResponseTypeDef",
-    "DetachLoadBalancerFromSubnetsInputTypeDef",
-    "DetachLoadBalancerFromSubnetsOutputResponseTypeDef",
+    "DeleteAccessPointInputRequestTypeDef",
+    "DeleteLoadBalancerListenerInputRequestTypeDef",
+    "DeleteLoadBalancerPolicyInputRequestTypeDef",
+    "DeregisterEndPointsInputRequestTypeDef",
+    "DeregisterEndPointsOutputTypeDef",
+    "DescribeAccessPointsInputRequestTypeDef",
+    "DescribeAccessPointsOutputTypeDef",
+    "DescribeAccountLimitsInputRequestTypeDef",
+    "DescribeAccountLimitsOutputTypeDef",
+    "DescribeEndPointStateInputRequestTypeDef",
+    "DescribeEndPointStateOutputTypeDef",
+    "DescribeLoadBalancerAttributesInputRequestTypeDef",
+    "DescribeLoadBalancerAttributesOutputTypeDef",
+    "DescribeLoadBalancerPoliciesInputRequestTypeDef",
+    "DescribeLoadBalancerPoliciesOutputTypeDef",
+    "DescribeLoadBalancerPolicyTypesInputRequestTypeDef",
+    "DescribeLoadBalancerPolicyTypesOutputTypeDef",
+    "DescribeTagsInputRequestTypeDef",
+    "DescribeTagsOutputTypeDef",
+    "DetachLoadBalancerFromSubnetsInputRequestTypeDef",
+    "DetachLoadBalancerFromSubnetsOutputTypeDef",
     "HealthCheckTypeDef",
     "InstanceStateTypeDef",
     "InstanceTypeDef",
@@ -74,8 +74,8 @@ __all__ = (
     "ListenerTypeDef",
     "LoadBalancerAttributesTypeDef",
     "LoadBalancerDescriptionTypeDef",
-    "ModifyLoadBalancerAttributesInputTypeDef",
-    "ModifyLoadBalancerAttributesOutputResponseTypeDef",
+    "ModifyLoadBalancerAttributesInputRequestTypeDef",
+    "ModifyLoadBalancerAttributesOutputTypeDef",
     "PaginatorConfigTypeDef",
     "PoliciesTypeDef",
     "PolicyAttributeDescriptionTypeDef",
@@ -83,15 +83,15 @@ __all__ = (
     "PolicyAttributeTypeDescriptionTypeDef",
     "PolicyDescriptionTypeDef",
     "PolicyTypeDescriptionTypeDef",
-    "RegisterEndPointsInputTypeDef",
-    "RegisterEndPointsOutputResponseTypeDef",
-    "RemoveAvailabilityZonesInputTypeDef",
-    "RemoveAvailabilityZonesOutputResponseTypeDef",
-    "RemoveTagsInputTypeDef",
+    "RegisterEndPointsInputRequestTypeDef",
+    "RegisterEndPointsOutputTypeDef",
+    "RemoveAvailabilityZonesInputRequestTypeDef",
+    "RemoveAvailabilityZonesOutputTypeDef",
+    "RemoveTagsInputRequestTypeDef",
     "ResponseMetadataTypeDef",
-    "SetLoadBalancerListenerSSLCertificateInputTypeDef",
-    "SetLoadBalancerPoliciesForBackendServerInputTypeDef",
-    "SetLoadBalancerPoliciesOfListenerInputTypeDef",
+    "SetLoadBalancerListenerSSLCertificateInputRequestTypeDef",
+    "SetLoadBalancerPoliciesForBackendServerInputRequestTypeDef",
+    "SetLoadBalancerPoliciesOfListenerInputRequestTypeDef",
     "SourceSecurityGroupTypeDef",
     "TagDescriptionTypeDef",
     "TagKeyOnlyTypeDef",
@@ -120,24 +120,24 @@ class AccessLogTypeDef(_RequiredAccessLogTypeDef, _OptionalAccessLogTypeDef):
     pass
 
 
-AddAvailabilityZonesInputTypeDef = TypedDict(
-    "AddAvailabilityZonesInputTypeDef",
+AddAvailabilityZonesInputRequestTypeDef = TypedDict(
+    "AddAvailabilityZonesInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "AvailabilityZones": List[str],
     },
 )
 
-AddAvailabilityZonesOutputResponseTypeDef = TypedDict(
-    "AddAvailabilityZonesOutputResponseTypeDef",
+AddAvailabilityZonesOutputTypeDef = TypedDict(
+    "AddAvailabilityZonesOutputTypeDef",
     {
         "AvailabilityZones": List[str],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-AddTagsInputTypeDef = TypedDict(
-    "AddTagsInputTypeDef",
+AddTagsInputRequestTypeDef = TypedDict(
+    "AddTagsInputRequestTypeDef",
     {
         "LoadBalancerNames": List[str],
         "Tags": List["TagTypeDef"],
@@ -162,32 +162,32 @@ AppCookieStickinessPolicyTypeDef = TypedDict(
     total=False,
 )
 
-ApplySecurityGroupsToLoadBalancerInputTypeDef = TypedDict(
-    "ApplySecurityGroupsToLoadBalancerInputTypeDef",
+ApplySecurityGroupsToLoadBalancerInputRequestTypeDef = TypedDict(
+    "ApplySecurityGroupsToLoadBalancerInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "SecurityGroups": List[str],
     },
 )
 
-ApplySecurityGroupsToLoadBalancerOutputResponseTypeDef = TypedDict(
-    "ApplySecurityGroupsToLoadBalancerOutputResponseTypeDef",
+ApplySecurityGroupsToLoadBalancerOutputTypeDef = TypedDict(
+    "ApplySecurityGroupsToLoadBalancerOutputTypeDef",
     {
         "SecurityGroups": List[str],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-AttachLoadBalancerToSubnetsInputTypeDef = TypedDict(
-    "AttachLoadBalancerToSubnetsInputTypeDef",
+AttachLoadBalancerToSubnetsInputRequestTypeDef = TypedDict(
+    "AttachLoadBalancerToSubnetsInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "Subnets": List[str],
     },
 )
 
-AttachLoadBalancerToSubnetsOutputResponseTypeDef = TypedDict(
-    "AttachLoadBalancerToSubnetsOutputResponseTypeDef",
+AttachLoadBalancerToSubnetsOutputTypeDef = TypedDict(
+    "AttachLoadBalancerToSubnetsOutputTypeDef",
     {
         "Subnets": List[str],
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -203,16 +203,16 @@ BackendServerDescriptionTypeDef = TypedDict(
     total=False,
 )
 
-ConfigureHealthCheckInputTypeDef = TypedDict(
-    "ConfigureHealthCheckInputTypeDef",
+ConfigureHealthCheckInputRequestTypeDef = TypedDict(
+    "ConfigureHealthCheckInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "HealthCheck": "HealthCheckTypeDef",
     },
 )
 
-ConfigureHealthCheckOutputResponseTypeDef = TypedDict(
-    "ConfigureHealthCheckOutputResponseTypeDef",
+ConfigureHealthCheckOutputTypeDef = TypedDict(
+    "ConfigureHealthCheckOutputTypeDef",
     {
         "HealthCheck": "HealthCheckTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -247,15 +247,15 @@ ConnectionSettingsTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateAccessPointInputTypeDef = TypedDict(
-    "_RequiredCreateAccessPointInputTypeDef",
+_RequiredCreateAccessPointInputRequestTypeDef = TypedDict(
+    "_RequiredCreateAccessPointInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "Listeners": List["ListenerTypeDef"],
     },
 )
-_OptionalCreateAccessPointInputTypeDef = TypedDict(
-    "_OptionalCreateAccessPointInputTypeDef",
+_OptionalCreateAccessPointInputRequestTypeDef = TypedDict(
+    "_OptionalCreateAccessPointInputRequestTypeDef",
     {
         "AvailabilityZones": List[str],
         "Subnets": List[str],
@@ -267,22 +267,22 @@ _OptionalCreateAccessPointInputTypeDef = TypedDict(
 )
 
 
-class CreateAccessPointInputTypeDef(
-    _RequiredCreateAccessPointInputTypeDef, _OptionalCreateAccessPointInputTypeDef
+class CreateAccessPointInputRequestTypeDef(
+    _RequiredCreateAccessPointInputRequestTypeDef, _OptionalCreateAccessPointInputRequestTypeDef
 ):
     pass
 
 
-CreateAccessPointOutputResponseTypeDef = TypedDict(
-    "CreateAccessPointOutputResponseTypeDef",
+CreateAccessPointOutputTypeDef = TypedDict(
+    "CreateAccessPointOutputTypeDef",
     {
         "DNSName": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-CreateAppCookieStickinessPolicyInputTypeDef = TypedDict(
-    "CreateAppCookieStickinessPolicyInputTypeDef",
+CreateAppCookieStickinessPolicyInputRequestTypeDef = TypedDict(
+    "CreateAppCookieStickinessPolicyInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "PolicyName": str,
@@ -290,15 +290,15 @@ CreateAppCookieStickinessPolicyInputTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateLBCookieStickinessPolicyInputTypeDef = TypedDict(
-    "_RequiredCreateLBCookieStickinessPolicyInputTypeDef",
+_RequiredCreateLBCookieStickinessPolicyInputRequestTypeDef = TypedDict(
+    "_RequiredCreateLBCookieStickinessPolicyInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "PolicyName": str,
     },
 )
-_OptionalCreateLBCookieStickinessPolicyInputTypeDef = TypedDict(
-    "_OptionalCreateLBCookieStickinessPolicyInputTypeDef",
+_OptionalCreateLBCookieStickinessPolicyInputRequestTypeDef = TypedDict(
+    "_OptionalCreateLBCookieStickinessPolicyInputRequestTypeDef",
     {
         "CookieExpirationPeriod": int,
     },
@@ -306,31 +306,31 @@ _OptionalCreateLBCookieStickinessPolicyInputTypeDef = TypedDict(
 )
 
 
-class CreateLBCookieStickinessPolicyInputTypeDef(
-    _RequiredCreateLBCookieStickinessPolicyInputTypeDef,
-    _OptionalCreateLBCookieStickinessPolicyInputTypeDef,
+class CreateLBCookieStickinessPolicyInputRequestTypeDef(
+    _RequiredCreateLBCookieStickinessPolicyInputRequestTypeDef,
+    _OptionalCreateLBCookieStickinessPolicyInputRequestTypeDef,
 ):
     pass
 
 
-CreateLoadBalancerListenerInputTypeDef = TypedDict(
-    "CreateLoadBalancerListenerInputTypeDef",
+CreateLoadBalancerListenerInputRequestTypeDef = TypedDict(
+    "CreateLoadBalancerListenerInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "Listeners": List["ListenerTypeDef"],
     },
 )
 
-_RequiredCreateLoadBalancerPolicyInputTypeDef = TypedDict(
-    "_RequiredCreateLoadBalancerPolicyInputTypeDef",
+_RequiredCreateLoadBalancerPolicyInputRequestTypeDef = TypedDict(
+    "_RequiredCreateLoadBalancerPolicyInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "PolicyName": str,
         "PolicyTypeName": str,
     },
 )
-_OptionalCreateLoadBalancerPolicyInputTypeDef = TypedDict(
-    "_OptionalCreateLoadBalancerPolicyInputTypeDef",
+_OptionalCreateLoadBalancerPolicyInputRequestTypeDef = TypedDict(
+    "_OptionalCreateLoadBalancerPolicyInputRequestTypeDef",
     {
         "PolicyAttributes": List["PolicyAttributeTypeDef"],
     },
@@ -338,8 +338,9 @@ _OptionalCreateLoadBalancerPolicyInputTypeDef = TypedDict(
 )
 
 
-class CreateLoadBalancerPolicyInputTypeDef(
-    _RequiredCreateLoadBalancerPolicyInputTypeDef, _OptionalCreateLoadBalancerPolicyInputTypeDef
+class CreateLoadBalancerPolicyInputRequestTypeDef(
+    _RequiredCreateLoadBalancerPolicyInputRequestTypeDef,
+    _OptionalCreateLoadBalancerPolicyInputRequestTypeDef,
 ):
     pass
 
@@ -351,47 +352,47 @@ CrossZoneLoadBalancingTypeDef = TypedDict(
     },
 )
 
-DeleteAccessPointInputTypeDef = TypedDict(
-    "DeleteAccessPointInputTypeDef",
+DeleteAccessPointInputRequestTypeDef = TypedDict(
+    "DeleteAccessPointInputRequestTypeDef",
     {
         "LoadBalancerName": str,
     },
 )
 
-DeleteLoadBalancerListenerInputTypeDef = TypedDict(
-    "DeleteLoadBalancerListenerInputTypeDef",
+DeleteLoadBalancerListenerInputRequestTypeDef = TypedDict(
+    "DeleteLoadBalancerListenerInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "LoadBalancerPorts": List[int],
     },
 )
 
-DeleteLoadBalancerPolicyInputTypeDef = TypedDict(
-    "DeleteLoadBalancerPolicyInputTypeDef",
+DeleteLoadBalancerPolicyInputRequestTypeDef = TypedDict(
+    "DeleteLoadBalancerPolicyInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "PolicyName": str,
     },
 )
 
-DeregisterEndPointsInputTypeDef = TypedDict(
-    "DeregisterEndPointsInputTypeDef",
+DeregisterEndPointsInputRequestTypeDef = TypedDict(
+    "DeregisterEndPointsInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "Instances": List["InstanceTypeDef"],
     },
 )
 
-DeregisterEndPointsOutputResponseTypeDef = TypedDict(
-    "DeregisterEndPointsOutputResponseTypeDef",
+DeregisterEndPointsOutputTypeDef = TypedDict(
+    "DeregisterEndPointsOutputTypeDef",
     {
         "Instances": List["InstanceTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DescribeAccessPointsInputTypeDef = TypedDict(
-    "DescribeAccessPointsInputTypeDef",
+DescribeAccessPointsInputRequestTypeDef = TypedDict(
+    "DescribeAccessPointsInputRequestTypeDef",
     {
         "LoadBalancerNames": List[str],
         "Marker": str,
@@ -400,8 +401,8 @@ DescribeAccessPointsInputTypeDef = TypedDict(
     total=False,
 )
 
-DescribeAccessPointsOutputResponseTypeDef = TypedDict(
-    "DescribeAccessPointsOutputResponseTypeDef",
+DescribeAccessPointsOutputTypeDef = TypedDict(
+    "DescribeAccessPointsOutputTypeDef",
     {
         "LoadBalancerDescriptions": List["LoadBalancerDescriptionTypeDef"],
         "NextMarker": str,
@@ -409,8 +410,8 @@ DescribeAccessPointsOutputResponseTypeDef = TypedDict(
     },
 )
 
-DescribeAccountLimitsInputTypeDef = TypedDict(
-    "DescribeAccountLimitsInputTypeDef",
+DescribeAccountLimitsInputRequestTypeDef = TypedDict(
+    "DescribeAccountLimitsInputRequestTypeDef",
     {
         "Marker": str,
         "PageSize": int,
@@ -418,8 +419,8 @@ DescribeAccountLimitsInputTypeDef = TypedDict(
     total=False,
 )
 
-DescribeAccountLimitsOutputResponseTypeDef = TypedDict(
-    "DescribeAccountLimitsOutputResponseTypeDef",
+DescribeAccountLimitsOutputTypeDef = TypedDict(
+    "DescribeAccountLimitsOutputTypeDef",
     {
         "Limits": List["LimitTypeDef"],
         "NextMarker": str,
@@ -427,14 +428,14 @@ DescribeAccountLimitsOutputResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredDescribeEndPointStateInputTypeDef = TypedDict(
-    "_RequiredDescribeEndPointStateInputTypeDef",
+_RequiredDescribeEndPointStateInputRequestTypeDef = TypedDict(
+    "_RequiredDescribeEndPointStateInputRequestTypeDef",
     {
         "LoadBalancerName": str,
     },
 )
-_OptionalDescribeEndPointStateInputTypeDef = TypedDict(
-    "_OptionalDescribeEndPointStateInputTypeDef",
+_OptionalDescribeEndPointStateInputRequestTypeDef = TypedDict(
+    "_OptionalDescribeEndPointStateInputRequestTypeDef",
     {
         "Instances": List["InstanceTypeDef"],
     },
@@ -442,37 +443,38 @@ _OptionalDescribeEndPointStateInputTypeDef = TypedDict(
 )
 
 
-class DescribeEndPointStateInputTypeDef(
-    _RequiredDescribeEndPointStateInputTypeDef, _OptionalDescribeEndPointStateInputTypeDef
+class DescribeEndPointStateInputRequestTypeDef(
+    _RequiredDescribeEndPointStateInputRequestTypeDef,
+    _OptionalDescribeEndPointStateInputRequestTypeDef,
 ):
     pass
 
 
-DescribeEndPointStateOutputResponseTypeDef = TypedDict(
-    "DescribeEndPointStateOutputResponseTypeDef",
+DescribeEndPointStateOutputTypeDef = TypedDict(
+    "DescribeEndPointStateOutputTypeDef",
     {
         "InstanceStates": List["InstanceStateTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DescribeLoadBalancerAttributesInputTypeDef = TypedDict(
-    "DescribeLoadBalancerAttributesInputTypeDef",
+DescribeLoadBalancerAttributesInputRequestTypeDef = TypedDict(
+    "DescribeLoadBalancerAttributesInputRequestTypeDef",
     {
         "LoadBalancerName": str,
     },
 )
 
-DescribeLoadBalancerAttributesOutputResponseTypeDef = TypedDict(
-    "DescribeLoadBalancerAttributesOutputResponseTypeDef",
+DescribeLoadBalancerAttributesOutputTypeDef = TypedDict(
+    "DescribeLoadBalancerAttributesOutputTypeDef",
     {
         "LoadBalancerAttributes": "LoadBalancerAttributesTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DescribeLoadBalancerPoliciesInputTypeDef = TypedDict(
-    "DescribeLoadBalancerPoliciesInputTypeDef",
+DescribeLoadBalancerPoliciesInputRequestTypeDef = TypedDict(
+    "DescribeLoadBalancerPoliciesInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "PolicyNames": List[str],
@@ -480,55 +482,55 @@ DescribeLoadBalancerPoliciesInputTypeDef = TypedDict(
     total=False,
 )
 
-DescribeLoadBalancerPoliciesOutputResponseTypeDef = TypedDict(
-    "DescribeLoadBalancerPoliciesOutputResponseTypeDef",
+DescribeLoadBalancerPoliciesOutputTypeDef = TypedDict(
+    "DescribeLoadBalancerPoliciesOutputTypeDef",
     {
         "PolicyDescriptions": List["PolicyDescriptionTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DescribeLoadBalancerPolicyTypesInputTypeDef = TypedDict(
-    "DescribeLoadBalancerPolicyTypesInputTypeDef",
+DescribeLoadBalancerPolicyTypesInputRequestTypeDef = TypedDict(
+    "DescribeLoadBalancerPolicyTypesInputRequestTypeDef",
     {
         "PolicyTypeNames": List[str],
     },
     total=False,
 )
 
-DescribeLoadBalancerPolicyTypesOutputResponseTypeDef = TypedDict(
-    "DescribeLoadBalancerPolicyTypesOutputResponseTypeDef",
+DescribeLoadBalancerPolicyTypesOutputTypeDef = TypedDict(
+    "DescribeLoadBalancerPolicyTypesOutputTypeDef",
     {
         "PolicyTypeDescriptions": List["PolicyTypeDescriptionTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DescribeTagsInputTypeDef = TypedDict(
-    "DescribeTagsInputTypeDef",
+DescribeTagsInputRequestTypeDef = TypedDict(
+    "DescribeTagsInputRequestTypeDef",
     {
         "LoadBalancerNames": List[str],
     },
 )
 
-DescribeTagsOutputResponseTypeDef = TypedDict(
-    "DescribeTagsOutputResponseTypeDef",
+DescribeTagsOutputTypeDef = TypedDict(
+    "DescribeTagsOutputTypeDef",
     {
         "TagDescriptions": List["TagDescriptionTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DetachLoadBalancerFromSubnetsInputTypeDef = TypedDict(
-    "DetachLoadBalancerFromSubnetsInputTypeDef",
+DetachLoadBalancerFromSubnetsInputRequestTypeDef = TypedDict(
+    "DetachLoadBalancerFromSubnetsInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "Subnets": List[str],
     },
 )
 
-DetachLoadBalancerFromSubnetsOutputResponseTypeDef = TypedDict(
-    "DetachLoadBalancerFromSubnetsOutputResponseTypeDef",
+DetachLoadBalancerFromSubnetsOutputTypeDef = TypedDict(
+    "DetachLoadBalancerFromSubnetsOutputTypeDef",
     {
         "Subnets": List[str],
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -649,16 +651,16 @@ LoadBalancerDescriptionTypeDef = TypedDict(
     total=False,
 )
 
-ModifyLoadBalancerAttributesInputTypeDef = TypedDict(
-    "ModifyLoadBalancerAttributesInputTypeDef",
+ModifyLoadBalancerAttributesInputRequestTypeDef = TypedDict(
+    "ModifyLoadBalancerAttributesInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "LoadBalancerAttributes": "LoadBalancerAttributesTypeDef",
     },
 )
 
-ModifyLoadBalancerAttributesOutputResponseTypeDef = TypedDict(
-    "ModifyLoadBalancerAttributesOutputResponseTypeDef",
+ModifyLoadBalancerAttributesOutputTypeDef = TypedDict(
+    "ModifyLoadBalancerAttributesOutputTypeDef",
     {
         "LoadBalancerName": str,
         "LoadBalancerAttributes": "LoadBalancerAttributesTypeDef",
@@ -736,40 +738,40 @@ PolicyTypeDescriptionTypeDef = TypedDict(
     total=False,
 )
 
-RegisterEndPointsInputTypeDef = TypedDict(
-    "RegisterEndPointsInputTypeDef",
+RegisterEndPointsInputRequestTypeDef = TypedDict(
+    "RegisterEndPointsInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "Instances": List["InstanceTypeDef"],
     },
 )
 
-RegisterEndPointsOutputResponseTypeDef = TypedDict(
-    "RegisterEndPointsOutputResponseTypeDef",
+RegisterEndPointsOutputTypeDef = TypedDict(
+    "RegisterEndPointsOutputTypeDef",
     {
         "Instances": List["InstanceTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-RemoveAvailabilityZonesInputTypeDef = TypedDict(
-    "RemoveAvailabilityZonesInputTypeDef",
+RemoveAvailabilityZonesInputRequestTypeDef = TypedDict(
+    "RemoveAvailabilityZonesInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "AvailabilityZones": List[str],
     },
 )
 
-RemoveAvailabilityZonesOutputResponseTypeDef = TypedDict(
-    "RemoveAvailabilityZonesOutputResponseTypeDef",
+RemoveAvailabilityZonesOutputTypeDef = TypedDict(
+    "RemoveAvailabilityZonesOutputTypeDef",
     {
         "AvailabilityZones": List[str],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-RemoveTagsInputTypeDef = TypedDict(
-    "RemoveTagsInputTypeDef",
+RemoveTagsInputRequestTypeDef = TypedDict(
+    "RemoveTagsInputRequestTypeDef",
     {
         "LoadBalancerNames": List[str],
         "Tags": List["TagKeyOnlyTypeDef"],
@@ -787,8 +789,8 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-SetLoadBalancerListenerSSLCertificateInputTypeDef = TypedDict(
-    "SetLoadBalancerListenerSSLCertificateInputTypeDef",
+SetLoadBalancerListenerSSLCertificateInputRequestTypeDef = TypedDict(
+    "SetLoadBalancerListenerSSLCertificateInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "LoadBalancerPort": int,
@@ -796,8 +798,8 @@ SetLoadBalancerListenerSSLCertificateInputTypeDef = TypedDict(
     },
 )
 
-SetLoadBalancerPoliciesForBackendServerInputTypeDef = TypedDict(
-    "SetLoadBalancerPoliciesForBackendServerInputTypeDef",
+SetLoadBalancerPoliciesForBackendServerInputRequestTypeDef = TypedDict(
+    "SetLoadBalancerPoliciesForBackendServerInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "InstancePort": int,
@@ -805,8 +807,8 @@ SetLoadBalancerPoliciesForBackendServerInputTypeDef = TypedDict(
     },
 )
 
-SetLoadBalancerPoliciesOfListenerInputTypeDef = TypedDict(
-    "SetLoadBalancerPoliciesOfListenerInputTypeDef",
+SetLoadBalancerPoliciesOfListenerInputRequestTypeDef = TypedDict(
+    "SetLoadBalancerPoliciesOfListenerInputRequestTypeDef",
     {
         "LoadBalancerName": str,
         "LoadBalancerPort": int,
